import React, { useRef } from 'react';
import { View, StyleSheet, StatusBar, TouchableOpacity } from 'react-native';
import * as MapLibreRN from '@maplibre/maplibre-react-native';
import { VECTOR_MAP_HOST } from 'src/constants';
import { Colors } from 'src/theme';
import { SafeAreaView } from 'react-native-safe-area-context';
import { useNavigation } from '@react-navigation/native';
import ChevronLeft from 'assets/icons/chevron-left.svg';

const FullMapScreen = ({ route }: { route: any }) => {
  const { lat, lng } = route.params;
  const navigation = useNavigation();
  const mapRef = useRef<MapLibreRN.MapViewRef>(null);
  const cameraRef = useRef<MapLibreRN.CameraRef>(null);

  return (
    <SafeAreaView style={{ height: '100%' }}>
      <StatusBar translucent backgroundColor="transparent" />

      <MapLibreRN.MapView
        ref={mapRef}
        style={styles.map}
        mapStyle={VECTOR_MAP_HOST + '/nomadmania-maps.json'}
        rotateEnabled={false}
        attributionEnabled={false}
      >
        <MapLibreRN.Camera
          ref={cameraRef}
          defaultSettings={{ centerCoordinate: [lng, lat], zoomLevel: 12 }}
        />
        <MapLibreRN.MarkerView coordinate={[lng, lat]}>
          <View style={styles.marker} />
        </MapLibreRN.MarkerView>
      </MapLibreRN.MapView>
      <TouchableOpacity
        onPress={() => {
          navigation.goBack();
        }}
        style={styles.backButtonContainer}
      >
        <View style={styles.backButton}>
          <ChevronLeft fill={Colors.WHITE} />
        </View>
      </TouchableOpacity>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  map: {
    ...StyleSheet.absoluteFillObject
  },
  backButtonContainer: {
    position: 'absolute',
    width: 50,
    height: 50,
    top: 50,
    left: 10,
    justifyContent: 'center',
    alignItems: 'center',
    zIndex: 2
  },
  backButton: {
    width: 42,
    height: 42,
    borderRadius: 21,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: 'rgba(0, 0, 0, 0.3)'
  },
  marker: {
    width: 20,
    height: 20,
    borderRadius: 10,
    backgroundColor: Colors.ORANGE,
    borderWidth: 2,
    borderColor: Colors.WHITE
  }
});

export default FullMapScreen;
